import pytest
from ipdb import set_trace
from src.py_term_helpers import terminal_size, top_wrap, star_line, kv_print
from os import get_terminal_size
# needs the '-s' flag to run with prints

top_wrap("TESTING")


@pytest.fixture
def term_size():
    return get_terminal_size().columns


def test_term_size(term_size):
    print(f'\nterm_size is: {term_size} || test_size:{terminal_size()}')
    assert term_size is terminal_size()


def test_star_line():
    line_1 = star_line()
    line_2 = star_line("-")
    assert (line_1[0] and line_1[-1]) == "*"
    assert (line_2[0] and line_2[-1]) == "-"


def test_kv_print():
    my_dict = {"key": "value"}
    test_print = kv_print(my_dict)
    assert isinstance(test_print, str)
    splited = test_print.split("=>")
    assert "my_dict" in splited[0]
    assert ('key' and 'value') in splited[1]



from os import get_terminal_size, system
import inspect
import re

# If in pytest will sometimes throw "OSError: [Errno 25] Inappropriate ioctl for device" on .get_terminal_size()
term_size = 0
try:
    term_size = get_terminal_size().columns
except:
    term_size = 80


def terminal_size():
    return term_size


def top_wrap(string: str, char="*"):
    system("clear")
    term_wrap(string, char)


def term_wrap(string: str, char="*"):
    string, char = str(string), str(char)[0]
    star_line(char)
    center_string_stars(string, char)
    star_line(char)


def star_line(char="*"):
    output = str(char)[0] * term_size
    print(output)
    return output


def center_string_stars(string: str, char="*"):
    string, char = str(string), str(char)[0]
    if len(string) > term_size:
        string[0:term_size - 2]
    half_size = (term_size - len(string) - 2) / 2
    half_stars = char[0] * int(half_size)
    output = f"{half_stars} {string} {half_stars}"
    print(output)
    return output


def kv_print(obj):
    frame = inspect.currentframe()
    try:
        context = inspect.getframeinfo(frame.f_back).code_context
        caller_lines = ''.join([line.strip() for line in context])
        m = re.search(r'kv_print\s*\((.+?)\)$', caller_lines)
        if m:
            key = m.group(1)
            output = f'{key} => {obj}'
            print(output)
            return output
    finally:
        del frame
